Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(6439)

Unified Diff: chrome/browser/ui/autofill/autofill_dialog_view_delegate.h

Issue 144073004: rAc: remove bold section labels on linux_aura. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: ui::ResourceBundle::BoldOnlyIfItLooksGood() Created 6 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/autofill/autofill_dialog_view_delegate.h
diff --git a/chrome/browser/ui/autofill/autofill_dialog_view_delegate.h b/chrome/browser/ui/autofill/autofill_dialog_view_delegate.h
index 9371262c4061a3d3dc33a0071a1c689b1fbb354c..bfde672f2fac0c768896e51e052c21f9bce2d20f 100644
--- a/chrome/browser/ui/autofill/autofill_dialog_view_delegate.h
+++ b/chrome/browser/ui/autofill/autofill_dialog_view_delegate.h
@@ -11,6 +11,7 @@
#include "chrome/browser/ui/autofill/autofill_dialog_types.h"
#include "components/autofill/content/browser/wallet/required_action.h"
#include "components/autofill/core/browser/field_types.h"
+#include "ui/base/resource/resource_bundle.h"
#include "ui/base/ui_base_types.h"
#include "ui/gfx/image/image.h"
#include "ui/gfx/native_widget_types.h"
@@ -38,6 +39,13 @@ namespace autofill {
typedef std::map<ServerFieldType, gfx::Image> FieldIconMap;
+struct SectionLabel {
+ // Text that describes a section (e.g. Billing).
+ base::string16 text;
+ // The font style that |text| should be shown as.
+ ui::ResourceBundle::FontStyle font;
+};
+
// This class defines the interface to the controller that the dialog view sees.
class AutofillDialogViewDelegate {
public:
@@ -120,8 +128,8 @@ class AutofillDialogViewDelegate {
// section.
virtual ui::MenuModel* MenuModelForSection(DialogSection section) = 0;
- // Returns the label text used to describe the section (i.e. Billing).
- virtual base::string16 LabelForSection(DialogSection section) const = 0;
+ // Returns the label text and font that describe the section (i.e. Billing).
+ virtual SectionLabel LabelForSection(DialogSection section) const = 0;
// Returns the current state of suggestions for |section|.
virtual SuggestionState SuggestionStateForSection(DialogSection section) = 0;

Powered by Google App Engine
This is Rietveld 408576698